callee_param_index_for_local

Function callee_param_index_for_local 

pub fn callee_param_index_for_local(
    tcx: TyCtxt<'_>,
    callee: DefId,
    local: usize,
) -> Option<usize>
Return the callee argument index represented by a MIR local.

Contract annotations written with parameter names are parsed in the callee’s local namespace. MIR local _0 is the return place and argument locals are _1..=_arg_count, so callee local _1 denotes checkpoint argument 0.